﻿using Infragistics.Windows.DockManager;
using System.Collections.Generic;
using System.Windows;
using System.Windows.Controls;

namespace WPFContextMenu
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        ViewModel vm;
        public MainWindow()
        {
            InitializeComponent();
            vm = new ViewModel();
            this.DataContext = vm;
        }

        private void xamDockManager1_ActivePaneChanged(object sender, RoutedPropertyChangedEventArgs<Infragistics.Windows.DockManager.ContentPane> e)
        {
            if (e.NewValue != null)
            {
                vm.curActivePane = e.NewValue;
                vm.isNotFloating = (vm.curActivePane.PaneLocation != PaneLocation.Floating && vm.curActivePane.PaneLocation != PaneLocation.FloatingOnly);
                vm.isWithinDocHost = (vm.curActivePane.PaneLocation == PaneLocation.Document);
                //vm.areMultipleItemsWithinTabGroup = (this.tgp.Items.Count > 1);

                // add new >>
                // get document host split pane
                var dchSplitPane = this.dch1.Panes[0];
                // get parent tabgroup pane of active pane
                var activePaneTgpParent = vm.curActivePane?.Parent as TabGroupPane;
                // check parent tabgroup pane items count is multiple items
                vm.areMultipleItemsWithinTabGroup = (activePaneTgpParent?.Items.Count > 1);

                // get index of parent tabgroup pane in document host
                var activePaneTgpParentIndex = dchSplitPane.Panes.IndexOf(activePaneTgpParent);
                // check it is not last group, not first group
                vm.isWithoutFirstTabGroup = (activePaneTgpParentIndex > 0);
                vm.isWithoutLastTabGroup = (activePaneTgpParentIndex < dchSplitPane.Panes.Count - 1) && (activePaneTgpParentIndex > -1);
                // add new <<
            }
        }
        //Logic from previous question

        private void ContentPane_OptionsMenuOpening(object sender, Infragistics.Windows.DockManager.Events.PaneOptionsMenuOpeningEventArgs e)
        {
            ContentPane cp = e.OriginalSource as ContentPane;

            List<object> list = new List<object>();
            foreach (var item in e.Items)
            {
                list.Add(item);
            }

            //When ContentPane is floating - disable "AutoHide"
            if (cp.PaneLocation == PaneLocation.Floating || cp.PaneLocation == PaneLocation.FloatingOnly)
            {
                int autoHideIndex = findItemIndex(list, "Auto Hide");
                if (autoHideIndex != -1)
                {
                    MenuItem autoHideItem = e.Items[autoHideIndex] as MenuItem;
                    autoHideItem.IsEnabled = false;
                }
            }

            // When ContentPane is displayed within DocumentContentHost and there is a single pane within the corresponding TabGroupPane - this is actually not needed
            if (cp.PaneLocation == PaneLocation.Document && this.tgp.Items.Count == 1)
            {
                int[] indexes = new int[3];
                indexes[0] = findItemIndex(list, "Close All But This");
                indexes[1] = findItemIndex(list, "New Horizontal Tab Group");
                indexes[2] = findItemIndex(list, "New Vertical Tab Group");

                foreach (int idx in indexes)
                {
                    if (idx != -1)
                    {
                        MenuItem curItem = e.Items[idx] as MenuItem;
                        curItem.IsEnabled = false;
                    }
                }
            }
        }

        private int findItemIndex(List<object> items, string header)
        {
            return items.FindIndex(item => item.GetType() == typeof(MenuItem) && (item as MenuItem).Header.Equals(header));
        }

        private void AutoHideBtn_Click(object sender, RoutedEventArgs e)
        {
            vm.curActivePane.ExecuteCommand(ContentPaneCommands.CloseAllButThis);
        }

        private void Close_Click(object sender, RoutedEventArgs e)
        {
            vm.curActivePane.ExecuteCommand(ContentPaneCommands.Close);
        }

        private void CloseAll_Click(object sender, RoutedEventArgs e)
        {
            vm.curActivePane.ExecuteCommand(ContentPaneCommands.CloseAllButThis);
        }

        private void Floating_Click(object sender, RoutedEventArgs e)
        {
            vm.curActivePane.ExecuteCommand(ContentPaneCommands.ChangeToFloatingOnly);
        }

        private void Dockable_Click(object sender, RoutedEventArgs e)
        {
            vm.curActivePane.ExecuteCommand(ContentPaneCommands.ChangeToDockable);
        }

        private void TabbedDocument_Click(object sender, RoutedEventArgs e)
        {
            vm.curActivePane.ExecuteCommand(ContentPaneCommands.ChangeToDocument);
        }

        private void AutoHide_Click(object sender, RoutedEventArgs e)
        {
            vm.curActivePane.ExecuteCommand(ContentPaneCommands.TogglePinnedState);
        }

        private void Hide_Click(object sender, RoutedEventArgs e)
        {
            vm.curActivePane.ExecuteCommand(ContentPaneCommands.Close);
        }

        private void NHTG_Click(object sender, RoutedEventArgs e)
        {
            vm.curActivePane.ExecuteCommand(ContentPaneCommands.MoveToNewHorizontalGroup);
        }

        private void NVTGF_Click(object sender, RoutedEventArgs e)
        {
            vm.curActivePane.ExecuteCommand(ContentPaneCommands.MoveToNewVerticalGroup);
        }

        // add new >>
        private void MTPTG_Click(object sender, RoutedEventArgs e)
        {
            vm.curActivePane.ExecuteCommand(ContentPaneCommands.MoveToPreviousGroup);
        }

        private void MTNTG_Click(object sender, RoutedEventArgs e)
        {
            vm.curActivePane.ExecuteCommand(ContentPaneCommands.MoveToNextGroup);
        }
        // add new <<
    }
}
